@@ -2,6 +2,7 @@ use bytes::Buf;
 use futures::{ready, FutureExt, Stream};
 use serde::{Deserialize, Serialize};
 use std::{
+    convert::TryFrom,
     error::Error,
     fmt,
     marker::PhantomData,
@@ -40,6 +41,20 @@ impl fmt::Display for RecvError {
     }
 }
 
+impl TryFrom<TryRecvError> for RecvError {
+    type Error = TryRecvError;
+
+    fn try_from(err: TryRecvError) -> Result<Self, Self::Error> {
+        match err {
+            TryRecvError::Closed => Err(TryRecvError::Closed),
+            TryRecvError::Empty => Err(TryRecvError::Empty),
+            TryRecvError::RemoteReceive(err) => Ok(Self::RemoteReceive(err)),
+            TryRecvError::RemoteConnect(err) => Ok(Self::RemoteConnect(err)),
+            TryRecvError::RemoteListen(err) => Ok(Self::RemoteListen(err)),
+        }
+    }
+}
+
 impl Error for RecvError {}
 
 impl RecvError {
